@@ -2,6 +2,7 @@ import logging
 from typing import Iterable, Tuple
 
 import requests
+from sentry_sdk import capture_exception
 
 from appel_crises.settings import MTCAPTCHA_PRIVATE_KEY, DEBUG
 
@@ -32,6 +33,7 @@ def verify_captcha(token: str) -> Tuple[bool, Iterable[str]]:
         data = resp.json()
 
     except Exception as e:
+        capture_exception(e)
         _logger.error("Error while validating captcha token : %r", e)
         return True, ()
 
