@@ -46,9 +46,8 @@ ASSOCIATIONS = [
         "https://www.groupe-sos.org/transition-ecologique",
         "Groupe SOS Transition écologique",
     ),
-    ("https://www.i4ce.org/", "I4CE"),
     ("https://ilestencoretemps.fr/", "Il est Encore Temps"),
-    ("https://www.institut-rousseau.com/", "Institut Rousseau"),
+    ("https://www.institut-rousseau.fr/", "Institut Rousseau"),
     ("https://www.veblen-institute.org/", "Institut Veblen"),
     ("http://www.jac-asso.fr/", "Jeunes Ambassadeurs pour le Climat"),
     ("https://fresqueduclimat.org/", "La Fresque du Climat"),
@@ -73,10 +72,10 @@ ASSOCIATIONS = [
     ("https://resilience-france.org/", "Resilience"),
     ("https://sciencescitoyennes.org/", "Sciences Citoyennes"),
     ("https://sosmaires.org/", "SOS Maires"),
-    ("https://upforeurope.com/", "T4E - Up for Europe"),
-    ("http://tnova.fr/", "Terra Nova"),
+    ("https://www.together-for-earth.org/", "Together For Earth"),
     ("https://theshiftproject.org/", "The Shift Project"),
     ("http://unef.fr/", "UNEF"),
+    ("https://www.facebook.com/UnisPourLeClimat/", "Unis Pour Le Climat"),
     ("https://www.unicef.fr/", "UNICEF France"),
     ("https://www.facebook.com/groups/unis.pour.la.planete/", "Unis Pour La Planète"),
     ("https://www.uriopss-nouvelleaquitaine.fr/", "URIOPSS Nouvelle-Aquitaine"),
