@@ -12,7 +12,7 @@ GVT: List[MailingPerson] = [
         "Gouvernement (Ministère de l’Économie et des Finances)",
     ),
     mailing_person(
-        "guillaume.leforestier@ecologique-solidaire.gouv.fr",
+        "marine.braud@ecologique-solidaire.gouv.fr",
         "Gouvernement (Ministère de la Transition Écologique)",
     ),
 ]
