@@ -14,6 +14,7 @@ from typing import Dict, Iterable, Tuple, List
 import requests
 from django.db import transaction
 from django.utils import timezone
+from sentry_sdk import capture_exception
 
 from appel_crises.models import Signature
 from appel_crises.settings import SENDIN_BLUE_API_KEY
@@ -87,6 +88,8 @@ def send_and_save(payload: Dict, instance: object) -> bool:
                 # No action taken on failure; invalid mails will be
                 # retried ad infinitum.
                 logger.error("Invalid response on POST to send mail: %r", e)
+                logger.error("Associated response text: %s", response.text)
+                capture_exception(e)
                 return False
             else:
                 logger.debug("Mail to %r sent successfully", payload['to'])
@@ -151,10 +154,15 @@ def get_delivered_emails(offset: int, limit: int = 100) -> List[DeliveryResult]:
     """Fetch the delivered emails."""
     params = dict(offset=offset, limit=limit, event="delivered")
 
-    resp = requests.get(SB_FETCH_EVENTS_URL, params=params, headers=SB_HEADER)
-    data = resp.json()
+    try:
+        resp = requests.get(SB_FETCH_EVENTS_URL, params=params, headers=SB_HEADER)
+        data = resp.json()
+    except Exception as e:
+        capture_exception(e)
+        logger.error("Invalid response on GET to fetch delivered emails: %r", e)
+        return []
 
-    if not data or 'events' not in data:
+    if 'events' not in data:
         return []
 
     result = [(e['email'], datetime.fromisoformat(e['date'])) for e in data['events']]
@@ -204,9 +212,14 @@ def add_signatures_to_newsletter_list(signatures: Iterable[Signature]):
         'api-key': SENDIN_BLUE_API_KEY,
     }
 
-    response = requests.request(
-        "POST", SB_IMPORT_CONTACTS_URL, data=json.dumps(payload), headers=headers
-    )
-    response.raise_for_status()
+    try:
+        response = requests.post(
+            SB_IMPORT_CONTACTS_URL, data=json.dumps(payload), headers=headers
+        )
+        response.raise_for_status()
+    except Exception as e:
+        capture_exception(e)
+        logger.error("Invalid response on POST to add emails to newsletter: %r", e)
+        return None
 
     return response
