@@ -5,7 +5,8 @@ from typing import Iterable, List, Union
 
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
-from django.core.management import BaseCommand
+from . import BaseCommand
+from sentry_sdk import capture_message
 
 from appel_crises.data import DISTRICT_TO_MP
 from appel_crises.data.gvt import GVT
@@ -126,6 +127,7 @@ class Command(BaseCommand):
 
         if not sending_result:
             self.stderr.write(f"Sending mail to {signature} failed.")
+            capture_message(f"Sending mail to {signature} failed")
 
         return sending_result
 
@@ -168,5 +170,6 @@ class Command(BaseCommand):
 
         if not sending_result:
             self.stderr.write(f"Sending mail to {email} failed.")
+            capture_message(f"Sending mail to {email} failed")
 
         return sending_result
