@@ -1,6 +1,6 @@
 import time
 
-from django.core.management import BaseCommand
+from . import BaseCommand
 
 from appel_crises.mailer import add_signatures_to_newsletter_list
 from appel_crises.models import Signature
