@@ -426,6 +426,8 @@ function isCallOutFormValid() {
 
 function onCallOutFormInput() {
     if (isCallOutFormValid()) {
+        /* hack because it had no height on iPhone6 */
+        document.getElementById('mail-right-col').style.minHeight = '610px';
         showElementsOfClass("call-out-captcha");
         if (isCallOutCaptchaValid && callOutLegal.checked) {
             removeClass(callOutSubmitBtn, "is-disabled");
@@ -434,6 +436,7 @@ function onCallOutFormInput() {
         }
     } else {
         addClass(callOutSubmitBtn, "is-disabled");
+        document.getElementById('mail-right-col').style.minHeight = '450px';
         hideElementsOfClass("call-out-captcha");
     }
 }
@@ -505,3 +508,5 @@ displayIfJsElements();
 setTimeout(detectIfMtCaptchaIsWorking, 2000);
 insertEmailTemplate();
 multiLineSujectOnMobile();
+
+Sentry.init({ dsn: 'https://8843708aac354abdac2dcb62526d7d83@o386416.ingest.sentry.io/5220704' });
